# HiveNetCore

HiveNetCore is the core component of HiveNetAssembly, which provides the most commonly used basic objects and basic tool classes.

docs: https://hivenetassemble.readthedocs.io/zh_CN/latest/